        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 22 <strong>control</strong><br>0,2,3,6,7,13,14,15,17,19,21,28,30,31,32,34,36,40,43,46,47,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 21 <br>4,8,9,10,12,16,18,23,24,25,26,27,29,35,37,38,39,41,42,44,45';}
       if(rr==6 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>20</strong> miembros: 8 <br>1,5,11,20,22,33,48,49';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 22 <strong>control</strong><br>0,2,3,6,7,13,14,15,17,19,21,28,30,31,32,34,36,40,43,46,47,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 21 <br>4,8,9,10,12,16,18,23,24,25,26,27,29,35,37,38,39,41,42,44,45';}
       if(rr==29 && cc==3){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>20</strong> miembros: 8 <br>1,5,11,20,22,33,48,49';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 22 <strong>control</strong><br>0,2,3,6,7,13,14,15,17,19,21,28,30,31,32,34,36,40,43,46,47,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 21 <br>4,8,9,10,12,16,18,23,24,25,26,27,29,35,37,38,39,41,42,44,45';}
       if(rr==30 && cc==3){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>20</strong> miembros: 8 <br>1,5,11,20,22,33,48,49';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 22 <strong>control</strong><br>0,2,3,6,7,13,14,15,17,19,21,28,30,31,32,34,36,40,43,46,47,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 21 <br>4,8,9,10,12,16,18,23,24,25,26,27,29,35,37,38,39,41,42,44,45';}
       if(rr==31 && cc==3){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>20</strong> miembros: 8 <br>1,5,11,20,22,33,48,49';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 22 <strong>control</strong><br>0,2,3,6,7,13,14,15,17,19,21,28,30,31,32,34,36,40,43,46,47,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 21 <br>4,8,9,10,12,16,18,23,24,25,26,27,29,35,37,38,39,41,42,44,45';}
       if(rr==32 && cc==3){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>20</strong> miembros: 8 <br>1,5,11,20,22,33,48,49';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 22 <strong>control</strong><br>0,2,3,6,7,13,14,15,17,19,21,28,30,31,32,34,36,40,43,46,47,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 21 <br>4,8,9,10,12,16,18,23,24,25,26,27,29,35,37,38,39,41,42,44,45';}
       if(rr==33 && cc==3){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260813 a 00</strong> UTC HH+132 (rango:120-144)<br>grupo: <strong>3</strong> representante: <strong>20</strong> miembros: 8 <br>1,5,11,20,22,33,48,49';}
}
